@@ -38,23 +38,22 @@ The following table describes the size and accuracy of the 100% MobileNet
 on size 224 x 224:
 ----------------------------------------------------------------------------
 Width Multiplier (alpha) | ImageNet Acc |  Multiply-Adds (M) |  Params (M)
-----------------------------------------------------------------------------
+-------------------------|---------------|-------------------|--------------
 |   1.0 MobileNet-224    |    70.6 %     |        529        |     4.2     |
 |   0.75 MobileNet-224   |    68.4 %     |        325        |     2.6     |
 |   0.50 MobileNet-224   |    63.7 %     |        149        |     1.3     |
 |   0.25 MobileNet-224   |    50.6 %     |        41         |     0.5     |
-----------------------------------------------------------------------------
 
 The following table describes the performance of
 the 100 % MobileNet on various input sizes:
 ------------------------------------------------------------------------
-      Resolution      | ImageNet Acc | Multiply-Adds (M) | Params (M)
-------------------------------------------------------------------------
+Resolution      | ImageNet Acc | Multiply-Adds (M) | Params (M)
+----------------------|---------------|-------------------|----------------
 |  1.0 MobileNet-224  |    70.6 %    |        569        |     4.2     |
 |  1.0 MobileNet-192  |    69.1 %    |        418        |     4.2     |
 |  1.0 MobileNet-160  |    67.2 %    |        290        |     4.2     |
 |  1.0 MobileNet-128  |    64.4 %    |        186        |     4.2     |
-------------------------------------------------------------------------
+
 Reference:
   - [MobileNets: Efficient Convolutional Neural Networks
      for Mobile Vision Applications](
@@ -75,7 +74,7 @@ from tensorflow.python.platform import tf_logging as logging
 from tensorflow.python.util.tf_export import keras_export
 
 BASE_WEIGHT_PATH = (
-    "https://storage.googleapis.com/tensorflow/" "keras-applications/mobilenet/"
+    "https://storage.googleapis.com/tensorflow/keras-applications/mobilenet/"
 )
 layers = None
 
@@ -303,7 +302,7 @@ def MobileNet(
         inputs = img_input
 
     # Create model.
-    model = training.Model(inputs, x, name="mobilenet_%0.2f_%s" % (alpha, rows))
+    model = training.Model(inputs, x, name=f"mobilenet_{alpha:0.2f}_{rows}")
 
     # Load weights.
     if weights == "imagenet":
