@@ -31,11 +31,14 @@ import tensorflow.compat.v2 as tf
 
 from keras.layers.rnn import lstm
 from keras.layers.rnn.abstract_rnn_cell import AbstractRNNCell
+from keras.saving import serialization_lib
+from keras.saving.legacy import serialization as legacy_serialization
 from keras.utils import generic_utils
 from keras.utils import tf_inspect
 
 # isort: off
 from tensorflow.python.util.tf_export import tf_export
+from tensorflow.python.util.deprecation import deprecated
 
 
 class _RNNCellWrapper(AbstractRNNCell):
@@ -142,6 +145,7 @@ class _RNNCellWrapper(AbstractRNNCell):
         return cls(cell, **config)
 
 
+@deprecated(None, "Please use tf.keras.layers.RNN instead.")
 @tf_export("nn.RNNCellDropoutWrapper", v1=[])
 class DropoutWrapper(_RNNCellWrapper):
     """Operator adding dropout to inputs and outputs of the given cell."""
@@ -263,9 +267,9 @@ class DropoutWrapper(_RNNCellWrapper):
                             f"Parameter {attr} must be between 0 and 1. "
                             f"Received {const_prob}"
                         )
-                    setattr(self, "_%s" % attr, float(const_prob))
+                    setattr(self, f"_{attr}", float(const_prob))
                 else:
-                    setattr(self, "_%s" % attr, tensor_prob)
+                    setattr(self, f"_{attr}", tensor_prob)
 
         # Set variational_recurrent, seed before running the code below
         self._variational_recurrent = variational_recurrent
@@ -488,6 +492,7 @@ class DropoutWrapper(_RNNCellWrapper):
         )
 
 
+@deprecated(None, "Please use tf.keras.layers.RNN instead.")
 @tf_export("nn.RNNCellResidualWrapper", v1=[])
 class ResidualWrapper(_RNNCellWrapper):
     """RNNCell wrapper that ensures cell inputs are added to the outputs."""
@@ -507,7 +512,7 @@ class ResidualWrapper(_RNNCellWrapper):
         self._residual_fn = residual_fn
 
     def _call_wrapped_cell(self, inputs, state, cell_call_fn, **kwargs):
-        """Run the cell and then apply the residual_fn on its inputs to its outputs.
+        """Run the cell and apply the residual_fn.
 
         Args:
           inputs: cell inputs.
@@ -577,6 +582,7 @@ class ResidualWrapper(_RNNCellWrapper):
         )
 
 
+@deprecated(None, "Please use tf.keras.layers.RNN instead.")
 @tf_export("nn.RNNCellDeviceWrapper", v1=[])
 class DeviceWrapper(_RNNCellWrapper):
     """Operator that ensures an RNNCell runs on a particular device."""
@@ -653,12 +659,22 @@ def _parse_config_to_function(
     function_type = config.pop(func_type_attr_name)
     if function_type == "function":
         # Simple lookup in custom objects
-        function = generic_utils.deserialize_keras_object(
+        function = legacy_serialization.deserialize_keras_object(
             config[func_attr_name],
             custom_objects=custom_objects,
             printable_module_name="function in wrapper",
         )
     elif function_type == "lambda":
+        if serialization_lib.in_safe_mode():
+            raise ValueError(
+                "Requested the deserialization of a layer with a "
+                "Python `lambda` inside it. "
+                "This carries a potential risk of arbitrary code execution "
+                "and thus it is disallowed by default. If you trust the "
+                "source of the saved model, you can pass `safe_mode=False` to "
+                "the loading function in order to allow "
+                "`lambda` loading."
+            )
         # Unsafe deserialization from bytecode
         function = generic_utils.func_load(config[func_attr_name], globs=globs)
     else:
