@@ -38,8 +38,39 @@ def numpy_text(tensor, is_repr=False):
     return text
 
 
+class AutoCastVariableSpec(tf.types.experimental.TraceType):
+    """TraceType for AutoCastVariableSpec for tracing with tf.function.
+
+    This class implements the Type for AutoCastVariable used in tracing.
+    """
+
+    def __init__(self, value):
+        self._value = value
+
+    def is_subtype_of(self, other) -> bool:
+        """If the other spec is the same as `self`, return True."""
+        return self == other
+
+    def most_specific_common_supertype(self, others):
+        """`self` is the common supertype if all input types match it."""
+        return self if all(self == other for other in others) else None
+
+    def placeholder_value(self, placeholder_context=None):
+        """Use the AutoCastVariable value itself as a placeholder."""
+        return self._value
+
+    def _to_tensors(self, value):
+        return []
+
+    def __hash__(self) -> int:
+        return hash(id(self._value))
+
+    def __eq__(self, other) -> bool:
+        return self is other
+
+
 class AutoCastVariable(tf.Variable, tf.__internal__.types.Tensor):
-    """Variable that will cast itself to a different dtype in applicable contexts.
+    """Variable that casts itself to a different dtype in applicable contexts.
 
     This class wraps a floating-point `tf.Variable`. It emulates the variable
     interface and delegates to the wrapped variable, but it additionally will
@@ -72,13 +103,13 @@ class AutoCastVariable(tf.Variable, tf.__internal__.types.Tensor):
         """
         if not isinstance(variable, tf.Variable):
             raise ValueError(
-                "variable must be of type tf.ResourceVariable, but got: "
-                "%s" % variable
+                "variable must be of type tf.ResourceVariable, but got: %s"
+                % variable
             )
         if not variable.dtype.is_floating:
             raise ValueError(
-                "variable must be a floating point variable but has "
-                "type: %s" % variable.dtype.name
+                "variable must be a floating point variable but has type: %s"
+                % variable.dtype.name
             )
         self._variable = variable
         # 'delegate' means AutoCastVariable.op return self._variable.op, which
@@ -363,6 +394,9 @@ class AutoCastVariable(tf.Variable, tf.__internal__.types.Tensor):
     def get_shape(self):
         return self._variable.get_shape()
 
+    def __tf_tracing_type__(self, context):
+        return AutoCastVariableSpec(self)
+
     def _gather_saveables_for_checkpoint(self):
         # By delegating this method to the wrapped variable, checkpoints with
         # AutoCastVariables are identical to checkpoints with normal variables.
@@ -370,12 +404,16 @@ class AutoCastVariable(tf.Variable, tf.__internal__.types.Tensor):
         # on models with normal variables, and vice versa.
         return self._variable._gather_saveables_for_checkpoint()
 
-    def _map_resources(self, save_options):
+    def _export_to_saved_model_graph(
+        self, object_map, tensor_map, options, **kwargs
+    ):
         # By delegating this method to the wrapped variable, SavedModel with
         # AutoCastVariables are identical to SavedModel with normal variables.
-        obj_map, resource_map = self._variable._map_resources(save_options)
-        obj_map[self] = obj_map[self._variable]
-        return obj_map, resource_map
+        resource_list = self._variable._export_to_saved_model_graph(
+            object_map, tensor_map, options, **kwargs
+        )
+        object_map[self] = object_map[self._variable]
+        return resource_list
 
     # TODO(reedwm): Maybe encode the fact the variable is an AutoCastVariable in
     # to_proto().
